<?php
/**
 * WCFM plugin controllers
 *
 * Plugin Orders Controller
 *
 * @author 		WC Lovers
 * @package 	wcfm/controllers
 * @version   1.0.0
 */

class WCFM_Orders_Controller {
	
	public function __construct() {
		global $WCFM;
		
		$this->processing();
	}
	
	public function processing() {
		global $WCFM, $wpdb, $_POST;
		
		$length = $_POST['length'];
		$offset = $_POST['start'];
		
		$args = array(
							'posts_per_page'   => $length,
							'offset'           => $offset,
							'category'         => '',
							'category_name'    => '',
							'orderby'          => 'date',
							'order'            => 'DESC',
							'include'          => '',
							'exclude'          => '',
							'meta_key'         => '',
							'meta_value'       => '',
							'post_type'        => 'shop_order',
							'post_mime_type'   => '',
							'post_parent'      => '',
							//'author'	   => get_current_user_id(),
							'post_status'      => 'any',
							'suppress_filters' => true 
						);
		if( isset( $_POST['search'] ) && !empty( $_POST['search']['value'] )) $args['s'] = $_POST['search']['value'];
		
		$args = apply_filters( 'wcfm_orders_args', $args );
		
		$wcfm_orders_array = get_posts( $args );
		
		// Get Product Count
		$order_count = 0;
		$filtered_order_count = 0;
		$wcfm_orders_count = wp_count_posts('shop_order');
		$order_count = count($wcfm_orders_array);
		// Get Filtered Post Count
		$args['posts_per_page'] = -1;
		$args['offset'] = 0;
		$wcfm_filterd_orders_array = get_posts( $args );
		$filtered_order_count = count($wcfm_filterd_orders_array);
		
		
		// Generate Products JSON
		$wcfm_orders_json = '';
		$wcfm_orders_json = '{
															"draw": ' . $_POST['draw'] . ',
															"recordsTotal": ' . $order_count . ',
															"recordsFiltered": ' . $filtered_order_count . ',
															"data": ';
		if(!empty($wcfm_orders_array)) {
			$index = 0;
			$wcfm_orders_json_arr = array();
			foreach($wcfm_orders_array as $wcfm_orders_single) {
				$the_order = wc_get_order( $wcfm_orders_single );
				// Status
				$wcfm_orders_json_arr[$index][] =  '<span class="order-status tips wcicon-status-' . sanitize_title( $the_order->get_status() ) . ' text_tip" data-tip="' . wc_get_order_status_name( $the_order->get_status() ) . '"></span>';
				
				// Order
				if ( $the_order->user_id ) {
					$user_info = get_userdata( $the_order->user_id );
				}

				if ( ! empty( $user_info ) ) {

					$username = '';

					if ( $user_info->first_name || $user_info->last_name ) {
						$username .= esc_html( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), ucfirst( $user_info->first_name ), ucfirst( $user_info->last_name ) ) );
					} else {
						$username .= esc_html( ucfirst( $user_info->display_name ) );
					}

				} else {
					if ( $the_order->billing_first_name || $the_order->billing_last_name ) {
						$username = trim( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), $the_order->billing_first_name, $the_order->billing_last_name ) );
					} else if ( $the_order->billing_company ) {
						$username = trim( $the_order->billing_company );
					} else {
						$username = __( 'Guest', 'woocommerce' );
					}
				}

				$wcfm_orders_json_arr[$index][] =  '<a href="' . get_wcfm_view_order_url($wcfm_orders_single->ID, $the_order) . '" class="wcfm_order_title">#' . esc_attr( $the_order->get_order_number() ) . '</a> by ' . $username;
				
				// Purchased
				$wcfm_orders_json_arr[$index][] =  apply_filters( 'woocommerce_admin_order_item_count', sprintf( _n( '%d item', '%d items', $the_order->get_item_count(), 'woocommerce' ), $the_order->get_item_count() ), $the_order );
				
				// Ship to
				if ( $address = $the_order->get_formatted_shipping_address() ) {
					$ship_to = '<a class="wcfm_orders_address" target="_blank" href="' . esc_url( $the_order->get_shipping_address_map_url() ) . '">'. esc_html( preg_replace( '#<br\s*/?>#i', ', ', $address ) ) .'</a>';
				} else {
					//$ship_to .= '&ndash;';
				}

				if ( $the_order->get_shipping_method() ) {
					//$ship_to .= '<small class="meta">' . __( 'Via', $WCFM->text_domain ) . ' ' . esc_html( $the_order->get_shipping_method() ) . '</small>';
				}
			
				$wcfm_orders_json_arr[$index][] =  $ship_to;
				
				// Total
				$total = $the_order->get_formatted_order_total();

				if ( $the_order->payment_method_title ) {
					$total .= ' <small class="meta">' . __( 'Via', $WCFM->text_domain ) . ' ' . esc_html( $the_order->payment_method_title ) . '</small>';
				}
				$wcfm_orders_json_arr[$index][] =  $total;
				
				// Date
				if ( '0000-00-00 00:00:00' == $wcfm_orders_single->post_date ) {
					$t_time = $h_time = __( 'Unpublished', $WCFM->text_domain );
				} else {
					$t_time = get_the_time( __( 'Y/m/d g:i:s A', $WCFM->text_domain ), $wcfm_orders_single );
					$h_time = get_the_time( __( 'Y/m/d', $WCFM->text_domain ), $wcfm_orders_single );
				}

				$wcfm_orders_json_arr[$index][] = '<abbr title="' . esc_attr( $t_time ) . '">' . esc_html( apply_filters( 'post_date_column_time', $h_time, $wcfm_orders_single ) ) . '</abbr>';
				
				// Action
				$wcfm_orders_json_arr[$index][] =  apply_filters ( 'wcfm_orders_actions', '<a href="' . get_wcfm_view_order_url($wcfm_orders_single->ID, $the_order) . '"><span class="wcicon-view text_tip" data-tip="' . esc_attr__( 'View Details', $WCFM->text_domain ) . '"></span></a>', $wcfm_orders_single, $the_order );
				
				$index++;
			}												
		}
		if( !empty($wcfm_orders_json_arr) ) $wcfm_orders_json .= json_encode($wcfm_orders_json_arr);
		else $wcfm_orders_json .= '[]';
		$wcfm_orders_json .= '
													}';
													
		echo $wcfm_orders_json;
	}
}