<?php
/**
 * WCFM plugin controllers
 *
 * Plugin Products Manage Controller
 *
 * @author 		WC Lovers
 * @package 	wcfm/controllers
 * @version   1.0.0
 */

class WCFM_Products_Manage_Controller {
	
	public function __construct() {
		global $WCFM;
		
		$this->processing();
	}
	
	public function processing() {
		global $WCFM, $wpdb, $_POST;
		
		$wcfm_products_manage_form_data = array();
	  parse_str($_POST['wcfm_products_manage_form'], $wcfm_products_manage_form_data);
	  //print_r($wcfm_products_manage_form_data);
	  $wcfm_products_manage_messages = get_wcfm_products_manager_messages();
	  $has_error = false;
	  
	  if(isset($wcfm_products_manage_form_data['title']) && !empty($wcfm_products_manage_form_data['title'])) {
	  	$is_update = false;
	  	$is_publish = false;
	  	$current_user_id = get_current_user_id();
	  	                  
	  	if(isset($_POST['status']) && ($_POST['status'] == 'draft')) {
	  		$product_status = 'draft';
	  	} else {
				$product_status = 'publish';
			}
	  	
	  	// Creating new product
			$new_product = array(
				'post_title'   => wc_clean( $wcfm_products_manage_form_data['title'] ),
				'post_status'  => $product_status,
				'post_type'    => 'product',
				'post_excerpt' => $wcfm_products_manage_form_data['excerpt'],
				'post_content' => $_POST['description'],
				'post_author'  => $current_user_id
				//'post_name' => sanitize_title($wcfm_products_manage_form_data['title'])
			);
			
			if(isset($wcfm_products_manage_form_data['pro_id']) && $wcfm_products_manage_form_data['pro_id'] == 0) {
				if ($product_status != 'draft') {
					$is_publish = true;
				}
				$new_product_id = wp_insert_post( $new_product, true );
			} else { // For Update
				$is_update = true;
				$new_product['ID'] = $wcfm_products_manage_form_data['pro_id'];
				unset( $new_product['post_author'] );
				if( get_post_status( $new_product['ID'] ) != 'draft' ) {
					unset( $new_product['post_status'] );
				} else if( (get_post_status( $new_product['ID'] ) == 'draft') && ($product_status != 'draft') ) {
					$is_publish = true;
				}
				$new_product_id = wp_update_post( $new_product, true );
			}
			
			if(!is_wp_error($new_product_id)) {
				// For Update
				if($is_update) $new_product_id = $wcfm_products_manage_form_data['pro_id'];
				
				// Set Product SKU
				if(isset($wcfm_products_manage_form_data['sku']) && !empty($wcfm_products_manage_form_data['sku'])) {
					update_post_meta( $new_product_id, '_sku', $wcfm_products_manage_form_data['sku'] );
					$unique_sku = wc_product_has_unique_sku( $new_product_id, $wcfm_products_manage_form_data['sku'] );
					if ( ! $unique_sku ) {
						update_post_meta( $new_product_id, '_sku', '' );
						echo '{"status": false, "message": "' . $wcfm_products_manage_messages['sku_unique'] . '", "id": "' . $new_product_id . '", "redirect": "' . get_permalink( $new_product_id ) . '"}';
						$has_error = true;
					}
				} else {
				  update_post_meta( $new_product_id, '_sku', '' );
				}
				  
				// Set Product Type
				wp_set_object_terms( $new_product_id, $wcfm_products_manage_form_data['product_type'], 'product_type' );
				
				// Product Visibility
				if( isset( $wcfm_products_manage_form_data['visibility'] ) )
					update_post_meta( $new_product_id, '_visibility', $wcfm_products_manage_form_data['visibility'] );
				
				// Set Product Stock
				if(isset($wcfm_products_manage_form_data['manage_stock']) && ($wcfm_products_manage_form_data['manage_stock'] == 'enable')) {
					update_post_meta( $new_product_id, '_manage_stock', 'yes' );
					if(isset($wcfm_products_manage_form_data['stock_qty']) && !empty($wcfm_products_manage_form_data['stock_qty'])) {
						update_post_meta( $new_product_id, '_stock', $wcfm_products_manage_form_data['stock_qty'] );
					} else {
						update_post_meta( $new_product_id, '_stock', '' );
					}
					update_post_meta( $new_product_id, '_stock_status', $wcfm_products_manage_form_data['stock_status'] );
					update_post_meta( $new_product_id, '_backorders', $wcfm_products_manage_form_data['backorders'] );
				} else {
					update_post_meta( $new_product_id, '_manage_stock', 'no' );
					update_post_meta( $new_product_id, '_backorders', 'no' );
					update_post_meta( $new_product_id, '_stock', '' );
				}
				wc_update_product_stock_status( $new_product_id, $wcfm_products_manage_form_data['stock_status'] );
				
				if(isset($wcfm_products_manage_form_data['sold_individually']) && ($wcfm_products_manage_form_data['sold_individually'] == 'enable')) {
					update_post_meta( $new_product_id, '_sold_individually', 'yes' );
				} else {
					update_post_meta( $new_product_id, '_sold_individually', 'no' );
				}
				
				// Virtual Product
				if(isset($wcfm_products_manage_form_data['is_virtual']) && ($wcfm_products_manage_form_data['is_virtual'] == 'enable')) {
					update_post_meta( $new_product_id, '_virtual', 'yes' );
					
					// Set product shipping data
					update_post_meta( $new_product_id, '_weight', '' );
					update_post_meta( $new_product_id, '_length', '' );
					update_post_meta( $new_product_id, '_width', '' );
					update_post_meta( $new_product_id, '_height', '' );
				} else {
					update_post_meta( $new_product_id, '_virtual', 'no' );
					
					// Set product shipping data
					update_post_meta( $new_product_id, '_weight', wc_format_decimal($wcfm_products_manage_form_data['weight']) );
					update_post_meta( $new_product_id, '_length', wc_format_decimal($wcfm_products_manage_form_data['length']) );
					update_post_meta( $new_product_id, '_width', wc_format_decimal($wcfm_products_manage_form_data['width']) );
					update_post_meta( $new_product_id, '_height', wc_format_decimal($wcfm_products_manage_form_data['height']) );
				}
				
				// Save shipping class
				$shipping_class = '_no_shipping_class' == $wcfm_products_manage_form_data['shipping_class'] ? '' : wc_clean( $wcfm_products_manage_form_data['shipping_class'] );
				wp_set_object_terms( $new_product_id, (int)$shipping_class, 'product_shipping_class' );
				
				// Set Product Tax Data
				if ( wc_tax_enabled() ) {
					update_post_meta( $new_product_id, '_tax_status', $wcfm_products_manage_form_data['tax_status'] );
					update_post_meta( $new_product_id, '_tax_class', $wcfm_products_manage_form_data['tax_class'] );
				}
				
				// Set Product Attributes
				if(isset($wcfm_products_manage_form_data['attributes']) && !empty($wcfm_products_manage_form_data['attributes'])) {
					$pro_attributes = array();
					foreach($wcfm_products_manage_form_data['attributes'] as $attributes) {
						if(!empty($attributes['name']) && !empty($attributes['value'])) {
							
							$is_visible = 0;
							if(isset($attributes['is_visible'])) $is_visible = 1;
							
							$is_variation = 0;
							if(isset($attributes['is_variation'])) $is_variation = 1;
							if($wcfm_products_manage_form_data['product_type'] != 'variable') $is_variation = 0;
							
							$is_taxonomy = 0;
							if($attributes['is_taxonomy'] == 1) $is_taxonomy = 1;
							
							if($is_taxonomy) {
								$values_are_slugs = false;

								if ( isset( $attributes['value'] ) ) {
			
									// Select based attributes - Format values (posted values are slugs)
									if ( is_array( $attributes['value'] ) ) {
										$attribute_values           = array_map( 'sanitize_title', $attributes['value'] );
										$values_are_slugs = true;
			
									// Text based attributes - Posted values are term names - don't change to slugs
									} else {
										$attribute_values = array_map( 'stripslashes', array_map( 'strip_tags', explode( WC_DELIMITER, $attributes['value'] ) ) );
									}
			
									// Remove empty items in the array
									$attribute_values = array_filter( $attribute_values, 'strlen' );
			
								} else {
									$attribute_values = array();
								}
			
								// Update post terms
								if ( taxonomy_exists( $attributes['tax_name'] ) ) {
			
									foreach( $attribute_values as $key => $value ) {
										$term = get_term_by( $values_are_slugs ? 'slug' : 'name', trim( $value ), $attributes['tax_name'] );
			
										if ( $term ) {
											$attribute_values[ $key ] = intval( $term->term_id );
										} else {
											$term = wp_insert_term( trim( $value ), $attributes['tax_name'] );
											if ( isset( $term->term_id ) ) {
												$attribute_values[ $key ] = intval($term->term_id);
											}
										}
									}
			
									wp_set_object_terms( $new_product_id, $attribute_values, $attributes['tax_name'] );
								}
			
								if ( ! empty( $attribute_values ) ) {
									// Add attribute to array, but don't set values
									$pro_attributes[ sanitize_title( $attributes['tax_name'] ) ] = array(
										'name'         => wc_clean( $attributes['tax_name'] ),
										'value'        => '',
										'position'     => 0,
										'is_visible'   => $is_visible,
										'is_variation' => $is_variation,
										'is_taxonomy'  => $is_taxonomy
									);
								}

							} else {
								$attribute_values = '';
								$att_values = explode("|", $attributes['value']);
								foreach($att_values as $att_value) {
									if($attribute_values) $attribute_values .= WC_DELIMITER;
									$attribute_values .= trim($att_value);
								}
							
								$pro_attributes[ sanitize_title($attributes['name']) ] = array(
									'name'         => wc_clean( $attributes['name'] ),
									'value'        => $attribute_values,
									'position'     => 0,
									'is_visible'   => $is_visible,
									'is_variation' => $is_variation,
									'is_taxonomy'  => $is_taxonomy
								);
							}
						}
					}
					
					uasort( $pro_attributes, 'wc_product_attribute_uasort_comparison' );
					
					/**
					 * Unset removed attributes by looping over previous values and
					 * unsetting the terms.
					 */
					$old_attributes = array_filter( (array) maybe_unserialize( get_post_meta( $new_product_id, '_product_attributes', true ) ) );
			
					if ( ! empty( $old_attributes ) ) {
						foreach ( $old_attributes as $key => $value ) {
							if ( empty( $pro_attributes[ $key ] ) && ! empty( $value['is_taxonomy'] ) && taxonomy_exists( $key ) ) {
								wp_set_object_terms( $new_product_id, array(), $key );
							}
						}
					}
			
					/**
					 * After removed attributes are unset, we can set the new attribute data.
					 */
					update_post_meta( $new_product_id, '_product_attributes', $pro_attributes );
				}
				
				// Set Product Category
				if(isset($wcfm_products_manage_form_data['product_cats']) && !empty($wcfm_products_manage_form_data['product_cats'])) {
					$is_first = true;
					foreach($wcfm_products_manage_form_data['product_cats'] as $product_cats) {
						if(!empty($product_cats['undefined']) && ($product_cats['undefined'] != -1)) {
							if($is_first) {
								$is_first = false;
								wp_set_object_terms( $new_product_id, (int)$product_cats['undefined'], 'product_cat' );
							} else {
								wp_set_object_terms( $new_product_id, (int)$product_cats['undefined'], 'product_cat', true );
							}
						}
					}
				}
				
				// Set Product Tags
				if(isset($wcfm_products_manage_form_data['product_tags']) && !empty($wcfm_products_manage_form_data['product_tags'])) {
					wp_set_post_terms( $new_product_id, $wcfm_products_manage_form_data['product_tags'], 'product_tag' );
				}
				
				// For Update
				/*if($is_update) {
					// Remove post thumbnail
					$post_thumbnail_id = get_post_thumbnail_id( $new_product_id );
					if($post_thumbnail_id) wp_delete_attachment( $post_thumbnail_id );
					
					// Clean Img Gallery
					$galleries = get_post_meta( $new_product_id, '_product_image_gallery', true );
					if($galleries) $gallery_arr = explode(',', $galleries);
					if(!empty($gallery_arr)) {
						foreach($gallery_arr as $gallery_img_id) {
							wp_delete_attachment( $gallery_img_id );
						}
					}
				}*/
				
				// Set Product Featured Image
				$wp_upload_dir = wp_upload_dir();
				if(isset($wcfm_products_manage_form_data['featured_img']) && !empty($wcfm_products_manage_form_data['featured_img'])) {
					$featured_img = str_replace($wp_upload_dir['baseurl'], $wp_upload_dir['basedir'], $wcfm_products_manage_form_data['featured_img']);
					$featured_img_id = $this->wcfm_get_image_id($wcfm_products_manage_form_data['featured_img']); //asociatingProductImage($featured_img, $new_product_id);
					set_post_thumbnail( $new_product_id, $featured_img_id );
				} else {
					delete_post_thumbnail( $new_product_id );
				}
				
				// Set product basic options for simple and external products
				if($wcfm_products_manage_form_data['product_type'] != 'variable') {
					// Set product price
					update_post_meta( $new_product_id, '_regular_price', wc_format_decimal($wcfm_products_manage_form_data['regular_price']) );
					
					// Set product sale price
					if(isset($wcfm_products_manage_form_data['sale_price']) && !empty($wcfm_products_manage_form_data['sale_price'])) {
						update_post_meta( $new_product_id, '_sale_price', wc_format_decimal($wcfm_products_manage_form_data['sale_price']) );
						update_post_meta( $new_product_id, '_price', wc_format_decimal($wcfm_products_manage_form_data['sale_price']) );
					} else {
						update_post_meta( $new_product_id, '_sale_price', '' );
						update_post_meta( $new_product_id, '_price', wc_format_decimal($wcfm_products_manage_form_data['regular_price']) );
					}
					
					// Sale Price Dates
					if( isset($wcfm_products_manage_form_data['sale_date_from']) ) {
						$sale_date_from     = wc_clean( $wcfm_products_manage_form_data['sale_date_from'] );
						update_post_meta( $new_product_id, '_sale_price_dates_from', $sale_date_from ? strtotime( $sale_date_from ) : '' );
					}
					if( isset($wcfm_products_manage_form_data['sale_date_upto']) ) {
						$sale_date_upto       = wc_clean( $wcfm_products_manage_form_data['sale_date_upto'] );
						update_post_meta( $new_product_id, '_sale_price_dates_to', $sale_date_upto ? strtotime( $sale_date_upto ) : '' );
					}
				} else {
					// Create Variable Product Variations
					if(isset($wcfm_products_manage_form_data['variations']) && !empty($wcfm_products_manage_form_data['variations'])) {
					  foreach($wcfm_products_manage_form_data['variations'] as $variations) {
					  	$variation_status     = isset( $variations['enable'] ) ? 'publish' : 'private';
					  	
					  	$variation_id = absint ( $variations['id'] );
					  	
					  	// Generate a useful post title
					  	$variation_post_title = sprintf( __( 'Variation #%s of %s', 'woocommerce' ), absint( $variation_id ), esc_html( get_the_title( $new_product_id ) ) );
					  	
					  	if ( ! $variation_id ) { // Adding New Variation
								$variation = array(
									'post_title'   => $variation_post_title,
									'post_content' => '',
									'post_status'  => $variation_status,
									'post_author'  => $current_user_id,
									'post_parent'  => $new_product_id,
									'post_type'    => 'product_variation'
								);
						
								$variation_id = wp_insert_post( $variation );
								do_action( 'woocommerce_create_product_variation', $variation_id );
							} else { // Updating Variation
								$wpdb->update( $wpdb->posts, array( 'post_status' => $variation_status, 'post_title' => $variation_post_title ), array( 'ID' => $variation_id ) );

								do_action( 'woocommerce_update_product_variation', $variation_id );
							}
							
							// Only continue if we have a variation ID
							if ( ! $variation_id ) {
								continue;
							}
							
							// SKU 
							update_post_meta( $variation_id, '_sku', wc_clean( stripslashes( $variations['sku'] ) ) );
							$unique_sku = wc_product_has_unique_sku( $variation_id, wc_clean( stripslashes( $variations['sku'] ) ) );
							if ( ! $unique_sku ) {
								update_post_meta( $variation_id, '_sku', '' );
								if(!$has_error) echo '{"status": false, "message": "' . $wcfm_products_manage_messages['variation_sku_unique'] . '", "id": "' . $new_product_id . '"}';
								$has_error = true;
							}
							
							// Set Variation Price
							update_post_meta( $variation_id, '_regular_price', wc_format_decimal($variations['regular_price']) );
							if(isset($variations['sale_price']) && !empty($variations['sale_price'])) {
								update_post_meta( $variation_id, '_sale_price', wc_format_decimal($variations['sale_price']) );
								update_post_meta( $variation_id, '_price', wc_format_decimal($variations['sale_price']) );
							} else {
								update_post_meta( $variation_id, '_sale_price', '' );
								update_post_meta( $variation_id, '_price', wc_format_decimal($variations['regular_price']) );
							}
							update_post_meta( $variation_id, '_sale_price_dates_from', '' );
							update_post_meta( $variation_id, '_sale_price_dates_to', '' );
							
							// Set Variation Thumbnail
							if(isset($variations['image']) && !empty($variations['image'])) {
								$variation_img = str_replace($wp_upload_dir['baseurl'], $wp_upload_dir['basedir'], $variations['image']);
								$variation_img_id = $this->asociatingProductImage($variation_img, $variation_id);
								update_post_meta( $variation_id, '_thumbnail_id', absint( $variation_img_id ) );
							}
							
							// Set Variation Stock Data
							update_post_meta( $variation_id, '_manage_stock', isset( $variations['manage_stock'] ) ? 'yes' : 'no' );
							update_post_meta( $variation_id, '_backorders', $variations['backorders'] );
							update_post_meta( $variation_id, '_stock_status', $variations['stock_status'] );
							update_post_meta( $variation_id, '_stock', $variations['stock_qty'] );
							// Only update stock status to user setting if changed by the user, but do so before looking at stock levels at variation level
							if ( ! empty( $variations['stock_status'] ) ) {
								wc_update_product_stock_status( $variation_id, $variations['stock_status'] );
							}
							if(isset($variations['manage_stock']) && !empty($variations['manage_stock'])) {
								wc_update_product_stock( $variation_id, wc_stock_amount( $variations['stock_qty'] ) );
							} else {
								delete_post_meta( $variation_id, '_backorders' );
								delete_post_meta( $variation_id, '_stock' );
							}
							
							do_action( 'after_wcfm_products_variation_meta_save', $new_product_id, $variation_id, $variations, $wcfm_products_manage_form_data );
							
							// Update Attributes
							foreach($variations as $variation_ele_key => $variation_ele_val) {
								if(strrpos($variation_ele_key, "attribute_") !== false) {
									$updated_attribute_keys[] = $variation_ele_key;
									update_post_meta( $variation_id, $variation_ele_key, $variation_ele_val );
								}
							}
							
							// Remove old taxonomies attributes so data is kept up to date - first get attribute key names
							$delete_attribute_keys = $wpdb->get_col( $wpdb->prepare( "SELECT meta_key FROM {$wpdb->postmeta} WHERE meta_key LIKE 'attribute_%%' AND meta_key NOT IN ( '" . implode( "','", $updated_attribute_keys ) . "' ) AND post_id = %d;", $variation_id ) );
			
							foreach ( $delete_attribute_keys as $key ) {
								delete_post_meta( $variation_id, $key );
							}
							
							delete_transient( 'wc_product_children_' . $new_product_id );
						}
					}
					
					// Remove Variations
					if(isset($_POST['removed_variations']) && !empty($_POST['removed_variations'])) {
						foreach($_POST['removed_variations'] as $removed_variations) {
							wp_delete_post($removed_variations, true);
						}
					}
					
					// Variable and grouped products have no prices
					update_post_meta( $new_product_id, '_regular_price', '' );
					update_post_meta( $new_product_id, '_sale_price', '' );
					update_post_meta( $new_product_id, '_sale_price_dates_from', '' );
					update_post_meta( $new_product_id, '_sale_price_dates_to', '' );
					update_post_meta( $new_product_id, '_price', '' );
					
					WC_Product_Variable::sync( $new_product_id );
				}
				
				// If Product type External
				if($wcfm_products_manage_form_data['product_type'] == 'external') {
					update_post_meta( $new_product_id, '_product_url', $wcfm_products_manage_form_data['product_url'] );
					update_post_meta( $new_product_id, '_button_text', $wcfm_products_manage_form_data['button_text'] );
				}
				
				do_action( 'after_wcfm_products_manage_meta_save', $new_product_id, $wcfm_products_manage_form_data );
				
				// Notify Admin on New Product Creation
				if( $is_publish ) {
					$WCMp->product->on_all_status_transitions($product_status, '', get_post($new_product_id));
				} 
				
				if(!$has_error) {
					if( get_post_status( $new_product_id ) == 'publish' ) {
						if(!$has_error) echo '{"status": true, "message": "' . $wcfm_products_manage_messages['product_published'] . '", "redirect": "' . get_permalink( $new_product_id ) . '"}';	
					} else {
						if(!$has_error) echo '{"status": true, "message": "' . $wcfm_products_manage_messages['product_saved'] . '", "id": "' . $new_product_id . '"}';
					}
				}
				die;
			}
		} else {
			echo '{"status": false, "message": "' . $wcfm_products_manage_messages['no_title'] . '"}';
		}
		do_action('after_wcfm_frontend_product_manager_save', $new_product_id, $wcfm_products_manage_form_data);
	  die;
	}
	
	function wcfm_get_image_id($image_url) {
		global $wpdb;
		$attachment = $wpdb->get_col($wpdb->prepare("SELECT ID FROM $wpdb->posts WHERE guid='%s';", $image_url )); 
		return $attachment[0]; 
	}
	
	function asociatingProductImage($filename, $woo_pro_ID) {
		if(file_exists($filename)) {
			// Check the type of file. We'll use this as the 'post_mime_type'.
			$filetype = wp_check_filetype( basename( $filename ), null );
			
			// Upload the file
			$upload = wp_upload_bits( basename( $filename ), '', file_get_contents( $filename ) );
		
			if ( !$upload['error'] ) {
			
				// Prepare an array of post data for the attachment.
				$attachment = array(
					'guid'           => $upload['url'], 
					'post_mime_type' => $filetype['type'],
					'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $filename ) ),
					'post_content'   => '',
					'post_status'    => 'inherit',
					'post_parent'    => $woo_pro_ID
				);
				
				// Insert the attachment.
				$single_image_id = wp_insert_attachment( $attachment, $upload['file'] );
				
				if ( ! is_wp_error( $single_image_id ) ) {
					wp_update_attachment_metadata( $single_image_id, wp_generate_attachment_metadata( $single_image_id, $upload['file'] ) );
					return $single_image_id;
				}
			}
		}
		return 0;
	}
}