<?php

/**
 * WCFM plugin core
 *
 * Plugin intiate
 *
 * @author 		WC Lovers
 * @package 	wcfm/core
 * @version   1.0.0
 */
 
class WCFM {

	public $plugin_url;
	public $plugin_path;
	public $version;
	public $token;
	public $text_domain;
	public $wcfm_query;
	public $library;
	public $shortcode;
	public $admin;
	public $frontend;
	public $ajax;
	private $file;
	public $wcfm_fields;

	public function __construct($file) {

			$this->file = $file;
			$this->plugin_url = trailingslashit(plugins_url('', $plugin = $file));
			$this->plugin_path = trailingslashit(dirname($file));
			$this->token = WCFM_TOKEN;
			$this->text_domain = WCFM_TEXT_DOMAIN;
			$this->version = WCFM_VERSION;

			add_action('init', array(&$this, 'init'));
	}

	/**
	 * initilize plugin on WP init
	 */
	function init() {
			global $WCFM;

			// Init Text Domain
			$this->load_plugin_textdomain();
			
			// Init library
			$this->load_class('library');
			$this->library = new WCFM_Library();

			// Init ajax
			if (defined('DOING_AJAX')) {
				$this->load_class('ajax');
				$this->ajax = new WCFM_Ajax();
			}

			if (is_admin()) {
				$this->load_class('admin');
				$this->admin = new WCFM_Admin();
			}

			if (!is_admin() || defined('DOING_AJAX')) {
				$this->load_class('frontend');
				$this->frontend = new WCFM_Frontend();
			}

			// init shortcode
			$this->load_class('shortcode');
			$this->shortcode = new WCFM_Shortcode();


			// WCMp Fields Lib
      $this->wcfm_fields = $this->library->load_wcfm_fields();
	}

	/**
	 * Load Localisation files.
	 *
	 * Note: the first-loaded translation file overrides any following ones if the same translation is present
	 *
	 * @access public
	 * @return void
	 */
	public function load_plugin_textdomain() {
		$locale = apply_filters('plugin_locale', get_locale(), $this->token);

		load_textdomain($this->text_domain, WP_LANG_DIR . "/wc-frontend-manager/wc-frontend-manager-$locale.mo");
		load_textdomain($this->text_domain, $this->plugin_path . "/lang/wc-frontend-manager-$locale.mo");
	}

	public function load_class($class_name = '') {
		if ('' != $class_name && '' != $this->token) {
			require_once ('class-' . esc_attr($this->token) . '-' . esc_attr($class_name) . '.php');
		} // End If Statement
	}

	// End load_class()

	/**
	 * Install upon activation.
	 *
	 * @access public
	 * @return void
	 */
	static function activate_wcfm() {
		global $WCFM;

		require_once ( $WCFM->plugin_path . 'helpers/class-wcfm-install.php' );
		$WCFM_Install = new WCFM_Install();

		update_option('wcfm_installed', 1);
	}

	/**
	 * UnInstall upon deactivation.
	 *
	 * @access public
	 * @return void
	 */
	static function deactivate_wcfm() {
		global $WCFM;
		delete_option('wcfm_installed');
	}
	
	/** Cache Helpers ******************************************************** */

	/**
	 * Sets a constant preventing some caching plugins from caching a page. Used on dynamic pages
	 *
	 * @access public
	 * @return void
	 */
	function nocache() {
			if (!defined('DONOTCACHEPAGE'))
					define("DONOTCACHEPAGE", "true");
			// WP Super Cache constant
	}

}