<?php
global $wp, $WCFM, $theorder, $wpdb;

if ( ! is_object( $theorder ) ) {
	if( isset( $wp->query_vars['wcfm-orders-details'] ) && !empty( $wp->query_vars['wcfm-orders-details'] ) ) {
		$theorder = wc_get_order( $wp->query_vars['wcfm-orders-details'] );
	}
}

$order = $theorder;

self::init_address_fields();

if ( WC()->payment_gateways() ) {
	$payment_gateways = WC()->payment_gateways->payment_gateways();
} else {
	$payment_gateways = array();
}

$payment_method = ! empty( $order->payment_method ) ? $order->payment_method : '';

$order_type_object = get_post_type_object( $post->post_type );

// Get line items
$line_items          = $order->get_items( apply_filters( 'woocommerce_admin_order_item_types', 'line_item' ) );
$line_items_fee      = $order->get_items( 'fee' );
$line_items_shipping = $order->get_items( 'shipping' );

if ( wc_tax_enabled() ) {
	$order_taxes         = $order->get_taxes();
	$tax_classes         = WC_Tax::get_tax_classes();
	$classes_options     = array();
	$classes_options[''] = __( 'Standard', $WCFM->text_domain );

	if ( ! empty( $tax_classes ) ) {
		foreach ( $tax_classes as $class ) {
			$classes_options[ sanitize_title( $class ) ] = $class;
		}
	}

	// Older orders won't have line taxes so we need to handle them differently :(
	$tax_data = '';
	if ( $line_items ) {
		$check_item = current( $line_items );
		$tax_data   = maybe_unserialize( isset( $check_item['line_tax_data'] ) ? $check_item['line_tax_data'] : '' );
	} elseif ( $line_items_shipping ) {
		$check_item = current( $line_items_shipping );
		$tax_data = maybe_unserialize( isset( $check_item['taxes'] ) ? $check_item['taxes'] : '' );
	} elseif ( $line_items_fee ) {
		$check_item = current( $line_items_fee );
		$tax_data   = maybe_unserialize( isset( $check_item['line_tax_data'] ) ? $check_item['line_tax_data'] : '' );
	}

	$legacy_order     = ! empty( $order_taxes ) && empty( $tax_data ) && ! is_array( $tax_data );
	$show_tax_columns = ! $legacy_order || sizeof( $order_taxes ) === 1;
}

do_action( 'before_wcfm_orders_details' );
?>

<div class="collapse" id="wcfm_order_details">

	<?php do_action( 'begin_wcfm_orders_details' ); ?>
	
	<!-- collapsible -->
	<div class="page_collapsible orders_details_general" id="wcfm_general_options"><?php _e('Order Details', $WCFM->text_domain); ?><span></span></div>
	<div class="container">
		<div id="orders_details_general_expander" class="content">

			<p class="form-field form-field-wide"><label for="order_date"><?php _e( 'Order date:', $WCFM->text_domain ) ?></label>
				<?php echo date_i18n( 'Y-m-d', strtotime( $post->post_date ) ); ?> @<?php echo date_i18n( 'H', strtotime( $post->post_date ) ); ?>:<?php echo date_i18n( 'i', strtotime( $post->post_date ) ); ?>
			</p>
	
			<p class="form-field form-field-wide wc-order-status"><label for="order_status"><?php _e( 'Order status:', $WCFM->text_domain ) ?> <?php
					if ( $order->needs_payment() ) {
						printf( '<a href="%s">%s &rarr;</a>',
							esc_url( $order->get_checkout_payment_url() ),
							__( 'Customer payment page', $WCFM->text_domain )
						);
					}
				?></label>
				<?php
					$statuses = wc_get_order_statuses();
					foreach ( $statuses as $status => $status_name ) {
						if( $status == 'wc-' . $order->get_status() ) echo apply_filters( 'wcfm_order_status_modify', '<span class="order-status wcicon-status-' . sanitize_title( $order->get_status() ) . '"></span>&nbsp;' . esc_html( $status_name ), $order );
					}
				?>
			</p>

			<p class="form-field form-field-wide wc-customer-user">
				<label for="customer_user"><?php _e( 'Customer:', $WCFM->text_domain ) ?> <?php
					if ( ! empty( $order->customer_user ) ) {
						$args = array( 'post_status' => 'all',
							'post_type'      => 'shop_order',
							'_customer_user' => absint( $order->customer_user )
						);
						printf( '<a href="%s">%s &rarr;</a>',
							esc_url( add_query_arg( $args, admin_url( 'edit.php' ) ) ),
							__( 'View other orders', $WCFM->text_domain )
						);
					}
				?></label>
				<?php
				$user_string = '';
				$user_id     = '';
				if ( ! empty( $order->customer_user ) ) {
					$user_id     = absint( $order->customer_user );
					$user        = get_user_by( 'id', $user_id );
					$user_string = esc_html( $user->display_name ) . ' (#' . absint( $user->ID ) . ' - ' . esc_html( $user->user_email ) . ')';
				}
				echo htmlspecialchars( $user_string );
				?>
			</p>
			<?php do_action( 'woocommerce_admin_order_data_after_order_details', $order ); ?>
	
			<p class="order_number"><?php
	
				if ( $payment_method ) {
					printf( __( '<label for="order_payment_via">Payment via: </label> %s', $WCFM->text_domain ), ( isset( $payment_gateways[ $payment_method ] ) ? esc_html( $payment_gateways[ $payment_method ]->get_title() ) : esc_html( $payment_method ) ) );
	
					if ( $transaction_id = $order->get_transaction_id() ) {
							if ( isset( $payment_gateways[ $payment_method ] ) && ( $url = $payment_gateways[ $payment_method ]->get_transaction_url( $order ) ) ) {
							echo ' (<a href="' . esc_url( $url ) . '" target="_blank">' . esc_html( $transaction_id ) . '</a>)';
						} else {
							echo ' (' . esc_html( $transaction_id ) . ')';
						}
					}
	
					if ( $order->paid_date ) {
						printf( ' ' . _x( 'on %s @ %s', 'on date at time', $WCFM->text_domain ), date_i18n( get_option( 'date_format' ), strtotime( $order->paid_date ) ), date_i18n( get_option( 'time_format' ), strtotime( $order->paid_date ) ) );
					}
	
					echo '. ';
				}
	
				if ( $ip_address = get_post_meta( $post->ID, '_customer_ip_address', true ) ) {
					echo __( 'Customer IP', $WCFM->text_domain ) . ': <span class="woocommerce-Order-customerIP">' . esc_html( $ip_address ) . '</span>';
				}
			?></p>
			
			<table>
				<thead>
					<tr>
						<th>
							<?php _e( 'Billing Details', $WCFM->text_domain ); ?>
						</th>
						<th>
							<?php _e( 'Shipping Details', $WCFM->text_domain ); ?>
						</th>
					</tr>
				</thead>
				<tbody>
					<tr>
						<td>
							<?php
								// Display values
								echo '<div class="address">';
	
								if ( $order->get_formatted_billing_address() ) {
									echo '<p><strong>' . __( 'Address', $WCFM->text_domain ) . ':</strong>' . wp_kses( $order->get_formatted_billing_address(), array( 'br' => array() ) ) . '</p>';
								} else {
									echo '<p class="none_set"><strong>' . __( 'Address', $WCFM->text_domain ) . ':</strong> ' . __( 'No billing address set.', $WCFM->text_domain ) . '</p>';
								}
	
								foreach ( self::$billing_fields as $key => $field ) {
									if ( isset( $field['show'] ) && false === $field['show'] ) {
										continue;
									}
	
									$field_name = 'billing_' . $key;
	
									if ( $order->$field_name ) {
										echo '<p><strong>' . esc_html( $field['label'] ) . ':</strong> ' . make_clickable( esc_html( $order->$field_name ) ) . '</p>';
									}
								}
	
								echo '</div>';
	
								do_action( 'woocommerce_admin_order_data_after_billing_address', $order );
								?>
						</td>
						<td>
							<?php
								// Display values
								echo '<div class="address">';
	
									if ( $order->get_formatted_shipping_address() ) {
										echo '<p><strong>' . __( 'Address', $WCFM->text_domain ) . ':</strong>' . wp_kses( $order->get_formatted_shipping_address(), array( 'br' => array() ) ) . '</p>';
									} else {
										echo '<p class="none_set"><strong>' . __( 'Address', $WCFM->text_domain ) . ':</strong> ' . __( 'No shipping address set.', $WCFM->text_domain ) . '</p>';
									}
	
									if ( ! empty( self::$shipping_fields ) ) {
										foreach ( self::$shipping_fields as $key => $field ) {
											if ( isset( $field['show'] ) && false === $field['show'] ) {
												continue;
											}
	
											$field_name = 'shipping_' . $key;
	
											if ( ! empty( $order->$field_name ) ) {
												echo '<p><strong>' . esc_html( $field['label'] ) . ':</strong> ' . make_clickable( esc_html( $order->$field_name ) ) . '</p>';
											}
										}
									}
	
									if ( apply_filters( 'woocommerce_enable_order_notes_field', 'yes' == get_option( 'woocommerce_enable_order_comments', 'yes' ) ) && $post->post_excerpt ) {
										echo '<p><strong>' . __( 'Customer Provided Note', $WCFM->text_domain ) . ':</strong> ' . nl2br( esc_html( $post->post_excerpt ) ) . '</p>';
									}
	
								echo '</div>';
								?>
						</td>
					</tbody>
				</table>
		</div>
	</div>
	<!-- end collapsible -->
	<div class="wcfm-clearfix"></div><br />
	<!-- collapsible -->
	<div class="page_collapsible orders_details_items" id="wcfm_orders_items_options"><?php _e('Order Items', $WCFM->text_domain); ?><span></span></div>
	<div class="container">
		<div id="orders_details_items_expander" class="content">
			<table cellpadding="0" cellspacing="0" class="woocommerce_order_items">
				<thead>
					<tr>
						<th class="item sortable" colspan="2" data-sort="string-ins"><?php _e( 'Item', $WCFM->text_domain ); ?></th>
						<?php do_action( 'woocommerce_admin_order_item_headers', $order ); ?>
						<th class="item_cost sortable" data-sort="float"><?php _e( 'Cost', $WCFM->text_domain ); ?></th>
						<th class="quantity sortable" data-sort="int"><?php _e( 'Qty', $WCFM->text_domain ); ?></th>
						<th class="line_cost sortable" data-sort="float"><?php _e( 'Total', $WCFM->text_domain ); ?></th>
						<?php
							if ( empty( $legacy_order ) && ! empty( $order_taxes ) ) :
								foreach ( $order_taxes as $tax_id => $tax_item ) :
									$tax_class      = wc_get_tax_class_by_tax_id( $tax_item['rate_id'] );
									$tax_class_name = isset( $classes_options[ $tax_class ] ) ? $classes_options[ $tax_class ] : __( 'Tax', $WCFM->text_domain );
									$column_label   = ! empty( $tax_item['label'] ) ? $tax_item['label'] : __( 'Tax', $WCFM->text_domain );
									$column_tip     = $tax_item['name'] . ' (' . $tax_class_name . ')';
									?>
									<th class="line_tax text_tip" data-tip="<?php echo esc_attr( $column_tip ); ?>">
										<?php echo esc_attr( $column_label ); ?>
										<input type="hidden" class="order-tax-id" name="order_taxes[<?php echo $tax_id; ?>]" value="<?php echo esc_attr( $tax_item['rate_id'] ); ?>">
										<a class="delete-order-tax" href="#" data-rate_id="<?php echo $tax_id; ?>"></a>
									</th>
									<?php
								endforeach;
							endif;
						?>
						<th class="wc-order-edit-line-item" width="1%">&nbsp;</th>
					</tr>
				</thead>
				<tbody id="order_line_items">
				<?php
					foreach ( $line_items as $item_id => $item ) {
						$_product  = $order->get_product_from_item( $item );
						$item_meta = $order->get_item_meta( $item_id );
		
						do_action( 'woocommerce_before_order_item_' . $item['type'] . '_html', $item_id, $item, $order );
						
						$product_link  = $_product ? get_wcfm_edit_product_url($_product->id, $_product) : '';
						$thumbnail     = $_product ? apply_filters( 'woocommerce_admin_order_item_thumbnail', $_product->get_image( 'thumbnail', array( 'title' => '' ), false ), $item_id, $item ) : '';
						$tax_data      = empty( $legacy_order ) && wc_tax_enabled() ? maybe_unserialize( isset( $item['line_tax_data'] ) ? $item['line_tax_data'] : '' ) : false;
						$item_total    = ( isset( $item['line_total'] ) ) ? esc_attr( wc_format_localized_price( $item['line_total'] ) ) : '';
						$item_subtotal = ( isset( $item['line_subtotal'] ) ) ? esc_attr( wc_format_localized_price( $item['line_subtotal'] ) ) : '';
						?>
						<tr class="item <?php echo apply_filters( 'woocommerce_admin_html_order_item_class', ( ! empty( $class ) ? $class : '' ), $item, $order ); ?>" data-order_item_id="<?php echo $item_id; ?>">
							<td class="thumb">
								<?php
									echo '<div class="wc-order-item-thumbnail">' . wp_kses_post( $thumbnail ) . '</div>';
								?>
							</td>
							<td class="name" data-sort-value="<?php echo esc_attr( $item['name'] ); ?>">
								<?php
									echo $product_link ? '<a href="' . esc_url( $product_link ) . '" class="wc-order-item-name">' .  esc_html( $item['name'] ) . '</a>' : '<div class="class="wc-order-item-name"">' . esc_html( $item['name'] ) . '</div>';
						
									if ( $_product && $_product->get_sku() ) {
										echo '<div class="wc-order-item-sku"><strong>' . __( 'SKU:', $WCFM->text_domain ) . '</strong> ' . esc_html( $_product->get_sku() ) . '</div>';
									}
						
									if ( ! empty( $item['variation_id'] ) ) {
										echo '<div class="wc-order-item-variation"><strong>' . __( 'Variation ID:', $WCFM->text_domain ) . '</strong> ';
										if ( ! empty( $item['variation_id'] ) && 'product_variation' === get_post_type( $item['variation_id'] ) ) {
											echo esc_html( $item['variation_id'] );
										} elseif ( ! empty( $item['variation_id'] ) ) {
											echo esc_html( $item['variation_id'] ) . ' (' . __( 'No longer exists', $WCFM->text_domain ) . ')';
										}
										echo '</div>';
									}
								?>
								<input type="hidden" class="order_item_id" name="order_item_id[]" value="<?php echo esc_attr( $item_id ); ?>" />
								<input type="hidden" name="order_item_tax_class[<?php echo absint( $item_id ); ?>]" value="<?php echo isset( $item['tax_class'] ) ? esc_attr( $item['tax_class'] ) : ''; ?>" />
						
								<?php do_action( 'woocommerce_before_order_itemmeta', $item_id, $item, $_product ) ?>
								
								<div class="view">
									<?php
										global $wpdb;
								
										if ( $metadata = $order->has_meta( $item_id ) ) {
											echo '<table cellspacing="0" class="display_meta">';
											foreach ( $metadata as $meta ) {
								
												// Skip hidden core fields
												if ( in_array( $meta['meta_key'], apply_filters( 'woocommerce_hidden_order_itemmeta', array(
													'_qty',
													'_tax_class',
													'_product_id',
													'_variation_id',
													'_line_subtotal',
													'_line_subtotal_tax',
													'_line_total',
													'_line_tax',
													'method_id',
													'cost'
												) ) ) ) {
													continue;
												}
								
												// Skip serialised meta
												if ( is_serialized( $meta['meta_value'] ) ) {
													continue;
												}
								
												// Get attribute data
												if ( taxonomy_exists( wc_sanitize_taxonomy_name( $meta['meta_key'] ) ) ) {
													$term               = get_term_by( 'slug', $meta['meta_value'], wc_sanitize_taxonomy_name( $meta['meta_key'] ) );
													$meta['meta_key']   = wc_attribute_label( wc_sanitize_taxonomy_name( $meta['meta_key'] ) );
													$meta['meta_value'] = isset( $term->name ) ? $term->name : $meta['meta_value'];
												} else {
													$meta['meta_key']   = wc_attribute_label( $meta['meta_key'], $_product );
												}
								
												echo '<tr><th>' . wp_kses_post( rawurldecode( $meta['meta_key'] ) ) . ':</th><td>' . wp_kses_post( wpautop( make_clickable( rawurldecode( $meta['meta_value'] ) ) ) ) . '</td></tr>';
											}
											echo '</table>';
										}
									?>
								</div>
								<div class="edit" style="display: none;">
									<table class="meta" cellspacing="0">
										<tbody class="meta_items">
										<?php
											if ( $metadata = $order->has_meta( $item_id )) {
												foreach ( $metadata as $meta ) {
								
													// Skip hidden core fields
													if ( in_array( $meta['meta_key'], apply_filters( 'woocommerce_hidden_order_itemmeta', array(
														'_qty',
														'_tax_class',
														'_product_id',
														'_variation_id',
														'_line_subtotal',
														'_line_subtotal_tax',
														'_line_total',
														'_line_tax',
														'method_id',
														'cost'
													) ) ) ) {
														continue;
													}
								
													// Skip serialised meta
													if ( is_serialized( $meta['meta_value'] ) ) {
														continue;
													}
								
													$meta['meta_key']   = rawurldecode( $meta['meta_key'] );
													$meta['meta_value'] = esc_textarea( rawurldecode( $meta['meta_value'] ) ); // using a <textarea />
													$meta['meta_id']    = absint( $meta['meta_id'] );
								
													echo '<tr data-meta_id="' . esc_attr( $meta['meta_id'] ) . '">
														<td>
															<input type="text" name="meta_key[' . $meta['meta_id'] . ']" value="' . esc_attr( $meta['meta_key'] ) . '" />
															<textarea name="meta_value[' . $meta['meta_id'] . ']">' . $meta['meta_value'] . '</textarea>
														</td>
														<td width="1%"><button class="remove_order_item_meta button">&times;</button></td>
													</tr>';
												}
											}
										?>
										</tbody>
										<tfoot>
											<tr>
												<td colspan="4"><button class="add_order_item_meta button"><?php _e( 'Add&nbsp;meta', $WCFM->text_domain ); ?></button></td>
											</tr>
										</tfoot>
									</table>
								</div>

								
								<?php do_action( 'woocommerce_after_order_itemmeta', $item_id, $item, $_product ) ?>
							</td>
						
							<?php do_action( 'woocommerce_admin_order_item_values', $_product, $item, absint( $item_id ) ); ?>
						
							<td class="item_cost" width="1%" data-sort-value="<?php echo esc_attr( $order->get_item_subtotal( $item, false, true ) ); ?>">
								<div class="view">
									<?php
										if ( isset( $item['line_total'] ) ) {
											echo wc_price( $order->get_item_total( $item, false, true ), array( 'currency' => $order->get_order_currency() ) );
						
											if ( isset( $item['line_subtotal'] ) && $item['line_subtotal'] != $item['line_total'] ) {
												echo '<span class="wc-order-item-discount">-' . wc_price( wc_format_decimal( $order->get_item_subtotal( $item, false, false ) - $order->get_item_total( $item, false, false ), '' ), array( 'currency' => $order->get_order_currency() ) ) . '</span>';
											}
										}
									?>
								</div>
							</td>
							<td class="quantity" width="1%">
								<div class="view">
									<?php
										echo '<small class="times">&times;</small> ' . ( isset( $item['qty'] ) ? esc_html( $item['qty'] ) : '1' );
						
										if ( $refunded_qty = $order->get_qty_refunded_for_item( $item_id ) ) {
											echo '<small class="refunded">' . ( $refunded_qty * -1 ) . '</small>';
										}
									?>
								</div>
								<div class="edit" style="display: none;">
									<?php $item_qty = esc_attr( $item['qty'] ); ?>
									<input type="number" step="<?php echo apply_filters( 'woocommerce_quantity_input_step', '1', $_product ); ?>" min="0" autocomplete="off" name="order_item_qty[<?php echo absint( $item_id ); ?>]" placeholder="0" value="<?php echo $item_qty; ?>" data-qty="<?php echo $item_qty; ?>" size="4" class="quantity" />
								</div>
								<div class="refund" style="display: none;">
									<input type="number" step="<?php echo apply_filters( 'woocommerce_quantity_input_step', '1', $_product ); ?>" min="0" max="<?php echo $item['qty']; ?>" autocomplete="off" name="refund_order_item_qty[<?php echo absint( $item_id ); ?>]" placeholder="0" size="4" class="refund_order_item_qty" />
								</div>
							</td>
							<td class="line_cost" width="1%" data-sort-value="<?php echo esc_attr( isset( $item['line_total'] ) ? $item['line_total'] : '' ); ?>">
								<div class="view">
									<?php
										if ( isset( $item['line_total'] ) ) {
											echo wc_price( $item['line_total'], array( 'currency' => $order->get_order_currency() ) );
										}
						
										if ( isset( $item['line_subtotal'] ) && $item['line_subtotal'] !== $item['line_total'] ) {
											echo '<span class="wc-order-item-discount">-' . wc_price( wc_format_decimal( $item['line_subtotal'] - $item['line_total'], '' ), array( 'currency' => $order->get_order_currency() ) ) . '</span>';
										}
						
										if ( $refunded = $order->get_total_refunded_for_item( $item_id ) ) {
											echo '<small class="refunded">' . wc_price( $refunded, array( 'currency' => $order->get_order_currency() ) ) . '</small>';
										}
									?>
								</div>
							</td>
						
							<?php
								if ( ! empty( $tax_data ) ) {
									foreach ( $order_taxes as $tax_item ) {
										$tax_item_id       = $tax_item['rate_id'];
										$tax_item_total    = isset( $tax_data['total'][ $tax_item_id ] ) ? $tax_data['total'][ $tax_item_id ] : '';
										$tax_item_subtotal = isset( $tax_data['subtotal'][ $tax_item_id ] ) ? $tax_data['subtotal'][ $tax_item_id ] : '';
										?>
										<td class="line_tax" width="1%">
											<div class="view">
												<?php
													if ( '' != $tax_item_total ) {
														echo wc_price( wc_round_tax_total( $tax_item_total ), array( 'currency' => $order->get_order_currency() ) );
													} else {
														echo '&ndash;';
													}
						
													if ( isset( $item['line_subtotal'] ) && $item['line_subtotal'] !== $item['line_total'] ) {
														echo '<span class="wc-order-item-discount">-' . wc_price( wc_round_tax_total( $tax_item_subtotal - $tax_item_total ), array( 'currency' => $order->get_order_currency() ) ) . '</span>';
													}
						
													if ( $refunded = $order->get_tax_refunded_for_item( $item_id, $tax_item_id ) ) {
														echo '<small class="refunded">' . wc_price( $refunded, array( 'currency' => $order->get_order_currency() ) ) . '</small>';
													}
												?>
											</div>
											<div class="edit" style="display: none;">
												<div class="split-input">
													<div class="input">
														<label><?php esc_attr_e( 'Pre-discount:', $WCFM->text_domain ); ?></label>
														<input type="text" name="line_subtotal_tax[<?php echo absint( $item_id ); ?>][<?php echo esc_attr( $tax_item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" value="<?php echo esc_attr( wc_format_localized_price( $tax_item_subtotal ) ); ?>" class="line_subtotal_tax wc_input_price" data-subtotal_tax="<?php echo esc_attr( wc_format_localized_price( $tax_item_subtotal ) ); ?>" data-tax_id="<?php echo esc_attr( $tax_item_id ); ?>" />
													</div>
													<div class="input">
														<label><?php esc_attr_e( 'Total:', $WCFM->text_domain ); ?></label>
														<input type="text" name="line_tax[<?php echo absint( $item_id ); ?>][<?php echo esc_attr( $tax_item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" value="<?php echo esc_attr( wc_format_localized_price( $tax_item_total ) ); ?>" class="line_tax wc_input_price" data-total_tax="<?php echo esc_attr( wc_format_localized_price( $tax_item_total ) ); ?>" data-tax_id="<?php echo esc_attr( $tax_item_id ); ?>" />
													</div>
												</div>
											</div>
											<div class="refund" style="display: none;">
												<input type="text" name="refund_line_tax[<?php echo absint( $item_id ); ?>][<?php echo esc_attr( $tax_item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" class="refund_line_tax wc_input_price" data-tax_id="<?php echo esc_attr( $tax_item_id ); ?>" />
											</div>
										</td>
										<?php
									}
								}
							?>
						
							<td class="wc-order-edit-line-item" width="1%">
								
							</td>
						</tr>

						<?php
		
						do_action( 'woocommerce_order_item_' . $item['type'] . '_html', $item_id, $item, $order );
					}
					do_action( 'woocommerce_admin_order_items_after_line_items', $order->id );
				?>
				</tbody>
				<tbody id="order_shipping_line_items">
				<?php
					$shipping_methods = WC()->shipping() ? WC()->shipping->load_shipping_methods() : array();
					foreach ( $line_items_shipping as $item_id => $item ) {
						?>
						<tr class="shipping <?php echo ( ! empty( $class ) ) ? $class : ''; ?>" data-order_item_id="<?php echo $item_id; ?>">
							<td class="thumb"><span class="wcicon-truck-2"></span></td>
						
							<td class="name">
								<div class="view">
									<?php echo ! empty( $item['name'] ) ? wc_clean( $item['name'] ) : __( 'Shipping', $WCFM->text_domain ); ?>
								</div>
								<div class="edit" style="display: none;">
									<input type="hidden" name="shipping_method_id[]" value="<?php echo esc_attr( $item_id ); ?>" />
									<input type="text" class="shipping_method_name" placeholder="<?php esc_attr_e( 'Shipping Name', $WCFM->text_domain ); ?>" name="shipping_method_title[<?php echo $item_id; ?>]" value="<?php echo ( isset( $item['name'] ) ) ? wc_clean( $item['name'] ) : ''; ?>" />
									<select class="shipping_method" name="shipping_method[<?php echo esc_attr( $item_id ); ?>]">
										<optgroup label="<?php esc_attr_e( 'Shipping Method', $WCFM->text_domain ); ?>">
											<option value=""><?php _e( 'N/A', $WCFM->text_domain ); ?></option>
											<?php
												$found_method = false;
						
												foreach ( $shipping_methods as $method ) {
													$method_id = isset( $item['method_id'] ) ? $item['method_id'] : '';
													$current_method = ( 0 === strpos( $method_id, $method->id ) ) ? $method_id : $method->id;
						
													echo '<option value="' . esc_attr( $current_method ) . '" ' . selected( $method_id == $current_method, true, false ) . '>' . esc_html( $method->get_method_title() ) . '</option>';
						
													if ( $method_id == $current_method ) {
														$found_method = true;
													}
												}
						
												if ( ! $found_method && ! empty( $method_id ) ) {
													echo '<option value="' . esc_attr( $method_id ) . '" selected="selected">' . __( 'Other', $WCFM->text_domain ) . '</option>';
												} else {
													echo '<option value="other">' . __( 'Other', $WCFM->text_domain ) . '</option>';
												}
											?>
										</optgroup>
									</select>
								</div>
						
								<?php do_action( 'woocommerce_before_order_itemmeta', $item_id, $item, null ) ?>
								<div class="view">
									<?php
										global $wpdb;
								
										if ( $metadata = $order->has_meta( $item_id ) ) {
											echo '<table cellspacing="0" class="display_meta">';
											foreach ( $metadata as $meta ) {
								
												// Skip hidden core fields
												if ( in_array( $meta['meta_key'], apply_filters( 'woocommerce_hidden_order_itemmeta', array(
													'_qty',
													'_tax_class',
													'_product_id',
													'_variation_id',
													'_line_subtotal',
													'_line_subtotal_tax',
													'_line_total',
													'_line_tax',
													'method_id',
													'cost'
												) ) ) ) {
													continue;
												}
								
												// Skip serialised meta
												if ( is_serialized( $meta['meta_value'] ) ) {
													continue;
												}
								
												// Get attribute data
												if ( taxonomy_exists( wc_sanitize_taxonomy_name( $meta['meta_key'] ) ) ) {
													$term               = get_term_by( 'slug', $meta['meta_value'], wc_sanitize_taxonomy_name( $meta['meta_key'] ) );
													$meta['meta_key']   = wc_attribute_label( wc_sanitize_taxonomy_name( $meta['meta_key'] ) );
													$meta['meta_value'] = isset( $term->name ) ? $term->name : $meta['meta_value'];
												} else {
													$meta['meta_key']   = wc_attribute_label( $meta['meta_key'], $_product );
												}
								
												echo '<tr><th>' . wp_kses_post( rawurldecode( $meta['meta_key'] ) ) . ':</th><td>' . wp_kses_post( wpautop( make_clickable( rawurldecode( $meta['meta_value'] ) ) ) ) . '</td></tr>';
											}
											echo '</table>';
										}
									?>
								</div>
								<div class="edit" style="display: none;">
									<table class="meta" cellspacing="0">
										<tbody class="meta_items">
										<?php
											if ( $metadata = $order->has_meta( $item_id )) {
												foreach ( $metadata as $meta ) {
								
													// Skip hidden core fields
													if ( in_array( $meta['meta_key'], apply_filters( 'woocommerce_hidden_order_itemmeta', array(
														'_qty',
														'_tax_class',
														'_product_id',
														'_variation_id',
														'_line_subtotal',
														'_line_subtotal_tax',
														'_line_total',
														'_line_tax',
														'method_id',
														'cost'
													) ) ) ) {
														continue;
													}
								
													// Skip serialised meta
													if ( is_serialized( $meta['meta_value'] ) ) {
														continue;
													}
								
													$meta['meta_key']   = rawurldecode( $meta['meta_key'] );
													$meta['meta_value'] = esc_textarea( rawurldecode( $meta['meta_value'] ) ); // using a <textarea />
													$meta['meta_id']    = absint( $meta['meta_id'] );
								
													echo '<tr data-meta_id="' . esc_attr( $meta['meta_id'] ) . '">
														<td>
															<input type="text" name="meta_key[' . $meta['meta_id'] . ']" value="' . esc_attr( $meta['meta_key'] ) . '" />
															<textarea name="meta_value[' . $meta['meta_id'] . ']">' . $meta['meta_value'] . '</textarea>
														</td>
														<td width="1%"><button class="remove_order_item_meta button">&times;</button></td>
													</tr>';
												}
											}
										?>
										</tbody>
										<tfoot>
											<tr>
												<td colspan="4"><button class="add_order_item_meta button"><?php _e( 'Add&nbsp;meta', $WCFM->text_domain ); ?></button></td>
											</tr>
										</tfoot>
									</table>
								</div>
								<?php do_action( 'woocommerce_after_order_itemmeta', $item_id, $item, null ) ?>
							</td>
						
							<?php do_action( 'woocommerce_admin_order_item_values', null, $item, absint( $item_id ) ); ?>
						
							<td class="item_cost" width="1%">&nbsp;</td>
							<td class="quantity" width="1%">&nbsp;</td>
						
							<td class="line_cost" width="1%">
								<div class="view">
									<?php
										echo ( isset( $item['cost'] ) ) ? wc_price( wc_round_tax_total( $item['cost'] ), array( 'currency' => $order->get_order_currency() ) ) : '';
						
										if ( $refunded = $order->get_total_refunded_for_item( $item_id, 'shipping' ) ) {
											echo '<small class="refunded">-' . wc_price( $refunded, array( 'currency' => $order->get_order_currency() ) ) . '</small>';
										}
									?>
								</div>
								<div class="edit" style="display: none;">
									<input type="text" name="shipping_cost[<?php echo $item_id; ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" value="<?php echo ( isset( $item['cost'] ) ) ? esc_attr( wc_format_localized_price( $item['cost'] ) ) : ''; ?>" class="line_total wc_input_price" />
								</div>
								<div class="refund" style="display: none;">
									<input type="text" name="refund_line_total[<?php echo absint( $item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" class="refund_line_total wc_input_price" />
								</div>
							</td>
						
							<?php
								if ( empty( $legacy_order ) && wc_tax_enabled() ) :
									$shipping_taxes = isset( $item['taxes'] ) ? $item['taxes'] : '';
									$tax_data       = maybe_unserialize( $shipping_taxes );
						
									foreach ( $order_taxes as $tax_item ) :
										$tax_item_id       = $tax_item['rate_id'];
										$tax_item_total    = isset( $tax_data[ $tax_item_id ] ) ? $tax_data[ $tax_item_id ] : '';
										?>
											<td class="line_tax" width="1%">
												<div class="view">
													<?php
														echo ( '' != $tax_item_total ) ? wc_price( wc_round_tax_total( $tax_item_total ), array( 'currency' => $order->get_order_currency() ) ) : '&ndash;';
						
														if ( $refunded = $order->get_tax_refunded_for_item( $item_id, $tax_item_id, 'shipping' ) ) {
															echo '<small class="refunded">-' . wc_price( $refunded, array( 'currency' => $order->get_order_currency() ) ) . '</small>';
														}
													?>
												</div>
												<div class="edit" style="display: none;">
													<input type="text" name="shipping_taxes[<?php echo absint( $item_id ); ?>][<?php echo esc_attr( $tax_item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" value="<?php echo ( isset( $tax_item_total ) ) ? esc_attr( wc_format_localized_price( $tax_item_total ) ) : ''; ?>" class="line_tax wc_input_price" />
												</div>
												<div class="refund" style="display: none;">
													<input type="text" name="refund_line_tax[<?php echo absint( $item_id ); ?>][<?php echo esc_attr( $tax_item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" class="refund_line_tax wc_input_price" data-tax_id="<?php echo esc_attr( $tax_item_id ); ?>" />
												</div>
											</td>
						
										<?php
									endforeach;
								endif;
							?>
						
							<td class="wc-order-edit-line-item">
								
							</td>
						</tr>
						<?php
					}
					do_action( 'woocommerce_admin_order_items_after_shipping', $order->id );
				?>
				</tbody>
				<tbody id="order_fee_line_items">
				<?php
					foreach ( $line_items_fee as $item_id => $item ) {
						?>
						<tr class="fee <?php echo ( ! empty( $class ) ) ? $class : ''; ?>" data-order_item_id="<?php echo $item_id; ?>">
							<td class="thumb"><span class="wcicon-plus"></span></td>
						
							<td class="name">
								<div class="view">
									<?php echo ! empty( $item['name'] ) ? esc_html( $item['name'] ) : __( 'Fee', $WCFM->text_domain ); ?>
								</div>
								<div class="edit" style="display: none;">
									<input type="text" placeholder="<?php esc_attr_e( 'Fee Name', $WCFM->text_domain ); ?>" name="order_item_name[<?php echo absint( $item_id ); ?>]" value="<?php echo ( isset( $item['name'] ) ) ? esc_attr( $item['name'] ) : ''; ?>" />
									<input type="hidden" class="order_item_id" name="order_item_id[]" value="<?php echo esc_attr( $item_id ); ?>" />
									<input type="hidden" name="order_item_tax_class[<?php echo absint( $item_id ); ?>]" value="<?php echo isset( $item['tax_class'] ) ? esc_attr( $item['tax_class'] ) : ''; ?>" />
								</div>
							</td>
						
							<?php do_action( 'woocommerce_admin_order_item_values', null, $item, absint( $item_id ) ); ?>
						
							<td class="item_cost" width="1%">&nbsp;</td>
							<td class="quantity" width="1%">&nbsp;</td>
						
							<td class="line_cost" width="1%">
								<div class="view">
									<?php
										echo ( isset( $item['line_total'] ) ) ? wc_price( wc_round_tax_total( $item['line_total'] ), array( 'currency' => $order->get_order_currency() ) ) : '';
						
										if ( $refunded = $order->get_total_refunded_for_item( $item_id, 'fee' ) ) {
											echo '<small class="refunded">-' . wc_price( $refunded, array( 'currency' => $order->get_order_currency() ) ) . '</small>';
										}
									?>
								</div>
								<div class="edit" style="display: none;">
									<input type="text" name="line_total[<?php echo absint( $item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" value="<?php echo ( isset( $item['line_total'] ) ) ? esc_attr( wc_format_localized_price( $item['line_total'] ) ) : ''; ?>" class="line_total wc_input_price" />
								</div>
								<div class="refund" style="display: none;">
									<input type="text" name="refund_line_total[<?php echo absint( $item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" class="refund_line_total wc_input_price" />
								</div>
							</td>
						
							<?php
								if ( empty( $legacy_order ) && wc_tax_enabled() ) :
									$line_tax_data = isset( $item['line_tax_data'] ) ? $item['line_tax_data'] : '';
									$tax_data      = maybe_unserialize( $line_tax_data );
						
									foreach ( $order_taxes as $tax_item ) :
										$tax_item_id       = $tax_item['rate_id'];
										$tax_item_total    = isset( $tax_data['total'][ $tax_item_id ] ) ? $tax_data['total'][ $tax_item_id ] : '';
										?>
											<td class="line_tax" width="1%">
												<div class="view">
													<?php
														echo ( '' != $tax_item_total ) ? wc_price( wc_round_tax_total( $tax_item_total ), array( 'currency' => $order->get_order_currency() ) ) : '&ndash;';
						
														if ( $refunded = $order->get_tax_refunded_for_item( $item_id, $tax_item_id, 'fee' ) ) {
															echo '<small class="refunded">-' . wc_price( $refunded, array( 'currency' => $order->get_order_currency() ) ) . '</small>';
														}
													?>
												</div>
												<div class="edit" style="display: none;">
													<input type="text" name="line_tax[<?php echo absint( $item_id ); ?>][<?php echo esc_attr( $tax_item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" value="<?php echo ( isset( $tax_item_total ) ) ? esc_attr( wc_format_localized_price( $tax_item_total ) ) : ''; ?>" class="line_tax wc_input_price" />
												</div>
												<div class="refund" style="display: none;">
													<input type="text" name="refund_line_tax[<?php echo absint( $item_id ); ?>][<?php echo esc_attr( $tax_item_id ); ?>]" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" class="refund_line_tax wc_input_price" data-tax_id="<?php echo esc_attr( $tax_item_id ); ?>" />
												</div>
											</td>
						
										<?php
									endforeach;
								endif;
							?>
						
							<td class="wc-order-edit-line-item">
								
							</td>
						</tr>
						<?php
					}
					do_action( 'woocommerce_admin_order_items_after_fees', $order->id );
				?>
				</tbody>
				<tbody id="order_refunds">
				<?php
					if ( $refunds = $order->get_refunds() ) {
						foreach ( $refunds as $refund ) {
							/**
							 * @var object $refund The refund object.
							 */
							$who_refunded = new WP_User( $refund->post->post_author );
							?>
							<tr class="refund <?php echo ( ! empty( $class ) ) ? $class : ''; ?>" data-order_refund_id="<?php echo $refund->id; ?>">
								<td class="thumb"><div></div></td>
							
								<td class="name">
									<?php
										echo esc_attr__( 'Refund', $WCFM->text_domain ) . ' #' . absint( $refund->id ) . ' - ' . esc_attr( date_i18n( get_option( 'date_format' ) . ', ' . get_option( 'time_format' ), strtotime( $refund->post->post_date ) ) );
							
										if ( $who_refunded->exists() ) {
											echo ' ' . esc_attr_x( 'by', 'Ex: Refund - $date >by< $username', $WCFM->text_domain ) . ' ' . '<abbr class="refund_by" title="' . esc_attr__( 'ID: ', $WCFM->text_domain ) . absint( $who_refunded->ID ) . '">' . esc_attr( $who_refunded->display_name ) . '</abbr>' ;
										}
									?>
									<?php if ( $refund->get_refund_reason() ) : ?>
										<p class="description"><?php echo esc_html( $refund->get_refund_reason() ); ?></p>
									<?php endif; ?>
									<input type="hidden" class="order_refund_id" name="order_refund_id[]" value="<?php echo esc_attr( $refund->id ); ?>" />
								</td>
							
								<?php do_action( 'woocommerce_admin_order_item_values', null, $refund, absint( $refund->id ) ); ?>
							
								<td class="item_cost" width="1%">&nbsp;</td>
								<td class="quantity" width="1%">&nbsp;</td>
							
								<td class="line_cost" width="1%">
									<div class="view">
										<?php echo wc_price( '-' . $refund->get_refund_amount() ); ?>
									</div>
								</td>
							
								<?php if ( ( ! isset( $legacy_order ) || ! $legacy_order ) && wc_tax_enabled() ) : for ( $i = 0;  $i < count( $order_taxes ); $i++ ) : ?>
									<td class="line_tax" width="1%"></td>
								<?php endfor; endif; ?>
							
								<td class="wc-order-edit-line-item">
									
								</td>
							</tr>
							<?php
						}
						do_action( 'woocommerce_admin_order_items_after_refunds', $order->id );
					}
				?>
				</tbody>
			</table>
			
			<div class="wc-order-data-row wc-order-totals-items wc-order-items-editable">
				<?php
					$coupons = $order->get_items( array( 'coupon' ) );
					if ( $coupons ) {
						?>
						<div class="wc-used-coupons">
							<ul class="wc_coupon_list"><?php
								echo '<li><strong>' . __( 'Coupon(s) Used', $WCFM->text_domain ) . '</strong></li>';
								foreach ( $coupons as $item_id => $item ) {
									$post_id = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM {$wpdb->posts} WHERE post_title = %s AND post_type = 'shop_coupon' AND post_status = 'publish' LIMIT 1;", $item['name'] ) );
			
									$link = $post_id ? add_query_arg( array( 'post' => $post_id, 'action' => 'edit' ), admin_url( 'post.php' ) ) : add_query_arg( array( 's' => $item['name'], 'post_status' => 'all', 'post_type' => 'shop_coupon' ), admin_url( 'edit.php' ) );
			
									echo '<li class="code"><a href="' . esc_url( $link ) . '" class="img_tip" data-tip="' . esc_attr( wc_price( $item['discount_amount'], array( 'currency' => $order->get_order_currency() ) ) ) . '"><span>' . esc_html( $item['name'] ). '</span></a></li>';
								}
							?></ul>
						</div>
						<?php
					}
				?>
				<table class="wc-order-totals">
					<tr>
						<td class="label"><span class="img_tip" data-tip="<?php _e( 'This is the total discount. Discounts are defined per line item.', $WCFM->text_domain ) ; ?>"></span> <?php _e( 'Discount', $WCFM->text_domain ); ?>:</td>
						<td width="1%"></td>
						<td class="total">
							<?php echo wc_price( $order->get_total_discount(), array( 'currency' => $order->get_order_currency() ) ); ?>
						</td>
					</tr>
			
					<?php do_action( 'woocommerce_admin_order_totals_after_discount', $order->id ); ?>
			
					<tr>
						<td class="label"><span class="img_tip" data-tip="<?php _e( 'This is the shipping and handling total costs for the order.', $WCFM->text_domain ) ; ?>"></span> <?php _e( 'Shipping', $WCFM->text_domain ); ?>:</td>
						<td width="1%"></td>
						<td class="total"><?php
							if ( ( $refunded = $order->get_total_shipping_refunded() ) > 0 ) {
								echo '<del>' . strip_tags( wc_price( $order->get_total_shipping(), array( 'currency' => $order->get_order_currency() ) ) ) . '</del> <ins>' . wc_price( $order->get_total_shipping() - $refunded, array( 'currency' => $order->get_order_currency() ) ) . '</ins>';
							} else {
								echo wc_price( $order->get_total_shipping(), array( 'currency' => $order->get_order_currency() ) );
							}
						?></td>
					</tr>
			
					<?php do_action( 'woocommerce_admin_order_totals_after_shipping', $order->id ); ?>
			
					<?php if ( wc_tax_enabled() ) : ?>
						<?php foreach ( $order->get_tax_totals() as $code => $tax ) : ?>
							<tr>
								<td class="label"><?php echo $tax->label; ?>:</td>
								<td width="1%"></td>
								<td class="total"><?php
									if ( ( $refunded = $order->get_total_tax_refunded_by_rate_id( $tax->rate_id ) ) > 0 ) {
										echo '<del>' . strip_tags( $tax->formatted_amount ) . '</del> <ins>' . wc_price( WC_Tax::round( $tax->amount, wc_get_price_decimals() ) - WC_Tax::round( $refunded, wc_get_price_decimals() ), array( 'currency' => $order->get_order_currency() ) ) . '</ins>';
									} else {
										echo $tax->formatted_amount;
									}
								?></td>
							</tr>
						<?php endforeach; ?>
					<?php endif; ?>
			
					<?php do_action( 'woocommerce_admin_order_totals_after_tax', $order->id ); ?>
			
					<tr>
						<td class="label"><?php _e( 'Order Total', $WCFM->text_domain ); ?>:</td>
						<td>
							
						</td>
						<td class="total">
							<div class="view"><?php echo $order->get_formatted_order_total(); ?></div>
							<div class="edit" style="display: none;">
								<input type="text" class="wc_input_price" id="_order_total" name="_order_total" placeholder="<?php echo wc_format_localized_price( 0 ); ?>" value="<?php echo ( isset( $data['_order_total'][0] ) ) ? esc_attr( wc_format_localized_price( $data['_order_total'][0] ) ) : ''; ?>" />
								<div class="clear"></div>
							</div>
						</td>
					</tr>
			
					<?php do_action( 'woocommerce_admin_order_totals_after_total', $order->id ); ?>
			
					<tr>
						<td class="label refunded-total"><?php _e( 'Refunded', $WCFM->text_domain ); ?>:</td>
						<td width="1%"></td>
						<td class="total refunded-total">-<?php echo wc_price( $order->get_total_refunded(), array( 'currency' => $order->get_order_currency() ) ); ?></td>
					</tr>
			
					<?php do_action( 'woocommerce_admin_order_totals_after_refunded', $order->id ); ?>
			
				</table>
				<div class="clear"></div>
			</div>
		</div>
	</div>
	<!-- end collapsible -->
	 
	<?php do_action( 'end_wcfm_orders_details' ); ?>
	
</div>


<?php
do_action( 'after_wcfm_orders_details' );
?>